package Locale::CLDR::Transformations::Any::Latin::Bopomofo;
# This file auto generated from Data\common\transforms\Latin-Bopomofo.xml
#	on Sat 24 Oct  9:19:23 am GMT

use version;

our $VERSION = version->declare('v0.28.1');

use v5.10.1;
use mro 'c3';
use utf8;
use if $^V ge v5.12.0, feature => 'unicode_strings';

use Moose;

BEGIN {
	die "Transliteration requires Perl 5.18 or above"
		unless $^V ge v5.18.0;
}

no warnings 'experimental::regex_sets';
has 'transforms' => (
	is => 'ro',
	isa => 'ArrayRef',
	init_arg => undef,
	default => sub { [
		qr/(?^umi:\G(?^u:(?[[\p{Latin} + \p{Mn}] + [1-5]])))/,
		{
			type => 'transform',
			data => [
			],
		},
		{
			type => 'conversion',
			data => [
				{
					before  => q((?^u:[ln])),
					after   => q(),
					replace => q((?^u:v)),
					result  => q(ü),
					revisit => 0,
				},
			],
		},
		{
			type => 'transform',
			data => [
				{
					from => q(Latin),
					to => q(NumericPinyin),
				},
			],
		},
		{
			type => 'conversion',
			data => [
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:bang)),
					result  => q(ㄅㄤ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:bang)),
					result  => q(ㄅㄤ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:beng)),
					result  => q(ㄅㄥ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:beng)),
					result  => q(ㄅㄥ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:biao)),
					result  => q(ㄅㄧㄠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:biao)),
					result  => q(ㄅㄧㄠ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:bian)),
					result  => q(ㄅㄧㄢ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:bian)),
					result  => q(ㄅㄧㄢ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:bing)),
					result  => q(ㄅㄧㄥ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:bing)),
					result  => q(ㄅㄧㄥ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:bai)),
					result  => q(ㄅㄞ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:bai)),
					result  => q(ㄅㄞ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:bei)),
					result  => q(ㄅㄟ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:bei)),
					result  => q(ㄅㄟ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:bao)),
					result  => q(ㄅㄠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:bao)),
					result  => q(ㄅㄠ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:ban)),
					result  => q(ㄅㄢ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ban)),
					result  => q(ㄅㄢ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:ben)),
					result  => q(ㄅㄣ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ben)),
					result  => q(ㄅㄣ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:bie)),
					result  => q(ㄅㄧㄝ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:bie)),
					result  => q(ㄅㄧㄝ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:bin)),
					result  => q(ㄅㄧㄣ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:bin)),
					result  => q(ㄅㄧㄣ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:bun)),
					result  => q(ㄅㄨㄣ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:bun)),
					result  => q(ㄅㄨㄣ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:ba)),
					result  => q(ㄅㄚ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ba)),
					result  => q(ㄅㄚ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:bo)),
					result  => q(ㄅㄛ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:bo)),
					result  => q(ㄅㄛ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:bi)),
					result  => q(ㄅㄧ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:bi)),
					result  => q(ㄅㄧ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:bu)),
					result  => q(ㄅㄨ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:bu)),
					result  => q(ㄅㄨ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:pang)),
					result  => q(ㄆㄤ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:pang)),
					result  => q(ㄆㄤ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:peng)),
					result  => q(ㄆㄥ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:peng)),
					result  => q(ㄆㄥ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:piao)),
					result  => q(ㄆㄧㄠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:piao)),
					result  => q(ㄆㄧㄠ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:pian)),
					result  => q(ㄆㄧㄢ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:pian)),
					result  => q(ㄆㄧㄢ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:ping)),
					result  => q(ㄆㄧㄥ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ping)),
					result  => q(ㄆㄧㄥ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:pai)),
					result  => q(ㄆㄞ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:pai)),
					result  => q(ㄆㄞ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:pei)),
					result  => q(ㄆㄟ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:pei)),
					result  => q(ㄆㄟ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:pao)),
					result  => q(ㄆㄠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:pao)),
					result  => q(ㄆㄠ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:pou)),
					result  => q(ㄆㄡ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:pou)),
					result  => q(ㄆㄡ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:pan)),
					result  => q(ㄆㄢ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:pan)),
					result  => q(ㄆㄢ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:pen)),
					result  => q(ㄆㄣ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:pen)),
					result  => q(ㄆㄣ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:pie)),
					result  => q(ㄆㄧㄝ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:pie)),
					result  => q(ㄆㄧㄝ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:pin)),
					result  => q(ㄆㄧㄣ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:pin)),
					result  => q(ㄆㄧㄣ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:pa)),
					result  => q(ㄆㄚ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:pa)),
					result  => q(ㄆㄚ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:po)),
					result  => q(ㄆㄛ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:po)),
					result  => q(ㄆㄛ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:pi)),
					result  => q(ㄆㄧ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:pi)),
					result  => q(ㄆㄧ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:pu)),
					result  => q(ㄆㄨ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:pu)),
					result  => q(ㄆㄨ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:mang)),
					result  => q(ㄇㄤ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:mang)),
					result  => q(ㄇㄤ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:meng)),
					result  => q(ㄇㄥ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:meng)),
					result  => q(ㄇㄥ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:miao)),
					result  => q(ㄇㄧㄠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:miao)),
					result  => q(ㄇㄧㄠ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:mian)),
					result  => q(ㄇㄧㄢ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:mian)),
					result  => q(ㄇㄧㄢ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:ming)),
					result  => q(ㄇㄧㄥ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ming)),
					result  => q(ㄇㄧㄥ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:mai)),
					result  => q(ㄇㄞ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:mai)),
					result  => q(ㄇㄞ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:mei)),
					result  => q(ㄇㄟ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:mei)),
					result  => q(ㄇㄟ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:mao)),
					result  => q(ㄇㄠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:mao)),
					result  => q(ㄇㄠ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:mou)),
					result  => q(ㄇㄡ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:mou)),
					result  => q(ㄇㄡ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:man)),
					result  => q(ㄇㄢ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:man)),
					result  => q(ㄇㄢ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:men)),
					result  => q(ㄇㄣ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:men)),
					result  => q(ㄇㄣ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:mie)),
					result  => q(ㄇㄧㄝ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:mie)),
					result  => q(ㄇㄧㄝ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:miu)),
					result  => q(ㄇㄧㄡ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:miu)),
					result  => q(ㄇㄧㄡ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:min)),
					result  => q(ㄇㄧㄣ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:min)),
					result  => q(ㄇㄧㄣ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:ma)),
					result  => q(ㄇㄚ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ma)),
					result  => q(ㄇㄚ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:mo)),
					result  => q(ㄇㄛ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:mo)),
					result  => q(ㄇㄛ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:me)),
					result  => q(ㄇㄜ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:me)),
					result  => q(ㄇㄜ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:mi)),
					result  => q(ㄇㄧ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:mi)),
					result  => q(ㄇㄧ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:mu)),
					result  => q(ㄇㄨ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:mu)),
					result  => q(ㄇㄨ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:fang)),
					result  => q(ㄈㄤ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:fang)),
					result  => q(ㄈㄤ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:feng)),
					result  => q(ㄈㄥ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:feng)),
					result  => q(ㄈㄥ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:fiao)),
					result  => q(ㄈㄧㄠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:fiao)),
					result  => q(ㄈㄧㄠ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:fei)),
					result  => q(ㄈㄟ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:fei)),
					result  => q(ㄈㄟ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:fou)),
					result  => q(ㄈㄡ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:fou)),
					result  => q(ㄈㄡ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:fan)),
					result  => q(ㄈㄢ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:fan)),
					result  => q(ㄈㄢ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:fen)),
					result  => q(ㄈㄣ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:fen)),
					result  => q(ㄈㄣ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:fa)),
					result  => q(ㄈㄚ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:fa)),
					result  => q(ㄈㄚ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:fo)),
					result  => q(ㄈㄛ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:fo)),
					result  => q(ㄈㄛ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:fu)),
					result  => q(ㄈㄨ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:fu)),
					result  => q(ㄈㄨ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:diang)),
					result  => q(ㄉㄧㄤ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:diang)),
					result  => q(ㄉㄧㄤ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:dang)),
					result  => q(ㄉㄤ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:dang)),
					result  => q(ㄉㄤ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:deng)),
					result  => q(ㄉㄥ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:deng)),
					result  => q(ㄉㄥ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:diao)),
					result  => q(ㄉㄧㄠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:diao)),
					result  => q(ㄉㄧㄠ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:dian)),
					result  => q(ㄉㄧㄢ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:dian)),
					result  => q(ㄉㄧㄢ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:ding)),
					result  => q(ㄉㄧㄥ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ding)),
					result  => q(ㄉㄧㄥ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:duan)),
					result  => q(ㄉㄨㄢ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:duan)),
					result  => q(ㄉㄨㄢ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:dong)),
					result  => q(ㄉㄨㄥ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:dong)),
					result  => q(ㄉㄨㄥ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:dai)),
					result  => q(ㄉㄞ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:dai)),
					result  => q(ㄉㄞ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:dei)),
					result  => q(ㄉㄟ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:dei)),
					result  => q(ㄉㄟ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:dao)),
					result  => q(ㄉㄠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:dao)),
					result  => q(ㄉㄠ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:dou)),
					result  => q(ㄉㄡ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:dou)),
					result  => q(ㄉㄡ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:dan)),
					result  => q(ㄉㄢ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:dan)),
					result  => q(ㄉㄢ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:den)),
					result  => q(ㄉㄣ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:den)),
					result  => q(ㄉㄣ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:dia)),
					result  => q(ㄉㄧㄚ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:dia)),
					result  => q(ㄉㄧㄚ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:die)),
					result  => q(ㄉㄧㄝ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:die)),
					result  => q(ㄉㄧㄝ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:diu)),
					result  => q(ㄉㄧㄡ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:diu)),
					result  => q(ㄉㄧㄡ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:din)),
					result  => q(ㄉㄧㄣ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:din)),
					result  => q(ㄉㄧㄣ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:duo)),
					result  => q(ㄉㄨㄛ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:duo)),
					result  => q(ㄉㄨㄛ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:dui)),
					result  => q(ㄉㄨㄟ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:dui)),
					result  => q(ㄉㄨㄟ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:dun)),
					result  => q(ㄉㄨㄣ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:dun)),
					result  => q(ㄉㄨㄣ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:da)),
					result  => q(ㄉㄚ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:da)),
					result  => q(ㄉㄚ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:de)),
					result  => q(ㄉㄜ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:de)),
					result  => q(ㄉㄜ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:di)),
					result  => q(ㄉㄧ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:di)),
					result  => q(ㄉㄧ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:du)),
					result  => q(ㄉㄨ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:du)),
					result  => q(ㄉㄨ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:tang)),
					result  => q(ㄊㄤ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:tang)),
					result  => q(ㄊㄤ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:teng)),
					result  => q(ㄊㄥ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:teng)),
					result  => q(ㄊㄥ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:tiao)),
					result  => q(ㄊㄧㄠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:tiao)),
					result  => q(ㄊㄧㄠ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:tian)),
					result  => q(ㄊㄧㄢ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:tian)),
					result  => q(ㄊㄧㄢ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:ting)),
					result  => q(ㄊㄧㄥ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ting)),
					result  => q(ㄊㄧㄥ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:tuan)),
					result  => q(ㄊㄨㄢ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:tuan)),
					result  => q(ㄊㄨㄢ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:tong)),
					result  => q(ㄊㄨㄥ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:tong)),
					result  => q(ㄊㄨㄥ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:tai)),
					result  => q(ㄊㄞ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:tai)),
					result  => q(ㄊㄞ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:tao)),
					result  => q(ㄊㄠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:tao)),
					result  => q(ㄊㄠ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:tou)),
					result  => q(ㄊㄡ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:tou)),
					result  => q(ㄊㄡ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:tan)),
					result  => q(ㄊㄢ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:tan)),
					result  => q(ㄊㄢ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:tie)),
					result  => q(ㄊㄧㄝ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:tie)),
					result  => q(ㄊㄧㄝ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:tuo)),
					result  => q(ㄊㄨㄛ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:tuo)),
					result  => q(ㄊㄨㄛ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:tui)),
					result  => q(ㄊㄨㄟ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:tui)),
					result  => q(ㄊㄨㄟ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:tun)),
					result  => q(ㄊㄨㄣ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:tun)),
					result  => q(ㄊㄨㄣ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:ta)),
					result  => q(ㄊㄚ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ta)),
					result  => q(ㄊㄚ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:te)),
					result  => q(ㄊㄜ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:te)),
					result  => q(ㄊㄜ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:ti)),
					result  => q(ㄊㄧ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ti)),
					result  => q(ㄊㄧ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:tu)),
					result  => q(ㄊㄨ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:tu)),
					result  => q(ㄊㄨ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:niang)),
					result  => q(ㄋㄧㄤ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:niang)),
					result  => q(ㄋㄧㄤ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:nang)),
					result  => q(ㄋㄤ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:nang)),
					result  => q(ㄋㄤ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:neng)),
					result  => q(ㄋㄥ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:neng)),
					result  => q(ㄋㄥ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:niao)),
					result  => q(ㄋㄧㄠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:niao)),
					result  => q(ㄋㄧㄠ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:nian)),
					result  => q(ㄋㄧㄢ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:nian)),
					result  => q(ㄋㄧㄢ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:ning)),
					result  => q(ㄋㄧㄥ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ning)),
					result  => q(ㄋㄧㄥ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:nuan)),
					result  => q(ㄋㄨㄢ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:nuan)),
					result  => q(ㄋㄨㄢ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:nong)),
					result  => q(ㄋㄨㄥ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:nong)),
					result  => q(ㄋㄨㄥ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:nai)),
					result  => q(ㄋㄞ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:nai)),
					result  => q(ㄋㄞ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:nei)),
					result  => q(ㄋㄟ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:nei)),
					result  => q(ㄋㄟ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:nao)),
					result  => q(ㄋㄠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:nao)),
					result  => q(ㄋㄠ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:nou)),
					result  => q(ㄋㄡ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:nou)),
					result  => q(ㄋㄡ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:nan)),
					result  => q(ㄋㄢ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:nan)),
					result  => q(ㄋㄢ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:nen)),
					result  => q(ㄋㄣ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:nen)),
					result  => q(ㄋㄣ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:nia)),
					result  => q(ㄋㄧㄚ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:nia)),
					result  => q(ㄋㄧㄚ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:nie)),
					result  => q(ㄋㄧㄝ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:nie)),
					result  => q(ㄋㄧㄝ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:niu)),
					result  => q(ㄋㄧㄡ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:niu)),
					result  => q(ㄋㄧㄡ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:nin)),
					result  => q(ㄋㄧㄣ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:nin)),
					result  => q(ㄋㄧㄣ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:nuo)),
					result  => q(ㄋㄨㄛ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:nuo)),
					result  => q(ㄋㄨㄛ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:nun)),
					result  => q(ㄋㄨㄣ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:nun)),
					result  => q(ㄋㄨㄣ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:nüe)),
					result  => q(ㄋㄩㄝ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:nüe)),
					result  => q(ㄋㄩㄝ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:nue)),
					result  => q(ㄋㄩㄝ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:nue)),
					result  => q(ㄋㄩㄝ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:na)),
					result  => q(ㄋㄚ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:na)),
					result  => q(ㄋㄚ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:ne)),
					result  => q(ㄋㄜ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ne)),
					result  => q(ㄋㄜ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:ni)),
					result  => q(ㄋㄧ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ni)),
					result  => q(ㄋㄧ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:nu)),
					result  => q(ㄋㄨ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:nu)),
					result  => q(ㄋㄨ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:nü)),
					result  => q(ㄋㄩ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:nü)),
					result  => q(ㄋㄩ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:liang)),
					result  => q(ㄌㄧㄤ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:liang)),
					result  => q(ㄌㄧㄤ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:lang)),
					result  => q(ㄌㄤ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:lang)),
					result  => q(ㄌㄤ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:leng)),
					result  => q(ㄌㄥ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:leng)),
					result  => q(ㄌㄥ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:liao)),
					result  => q(ㄌㄧㄠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:liao)),
					result  => q(ㄌㄧㄠ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:lian)),
					result  => q(ㄌㄧㄢ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:lian)),
					result  => q(ㄌㄧㄢ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:ling)),
					result  => q(ㄌㄧㄥ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ling)),
					result  => q(ㄌㄧㄥ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:luan)),
					result  => q(ㄌㄨㄢ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:luan)),
					result  => q(ㄌㄨㄢ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:long)),
					result  => q(ㄌㄨㄥ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:long)),
					result  => q(ㄌㄨㄥ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:lüan)),
					result  => q(ㄌㄩㄢ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:lüan)),
					result  => q(ㄌㄩㄢ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:lai)),
					result  => q(ㄌㄞ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:lai)),
					result  => q(ㄌㄞ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:lei)),
					result  => q(ㄌㄟ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:lei)),
					result  => q(ㄌㄟ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:lao)),
					result  => q(ㄌㄠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:lao)),
					result  => q(ㄌㄠ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:lou)),
					result  => q(ㄌㄡ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:lou)),
					result  => q(ㄌㄡ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:lan)),
					result  => q(ㄌㄢ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:lan)),
					result  => q(ㄌㄢ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:lia)),
					result  => q(ㄌㄧㄚ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:lia)),
					result  => q(ㄌㄧㄚ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:lie)),
					result  => q(ㄌㄧㄝ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:lie)),
					result  => q(ㄌㄧㄝ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:liu)),
					result  => q(ㄌㄧㄡ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:liu)),
					result  => q(ㄌㄧㄡ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:lin)),
					result  => q(ㄌㄧㄣ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:lin)),
					result  => q(ㄌㄧㄣ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:luo)),
					result  => q(ㄌㄨㄛ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:luo)),
					result  => q(ㄌㄨㄛ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:lun)),
					result  => q(ㄌㄨㄣ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:lun)),
					result  => q(ㄌㄨㄣ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:lüe)),
					result  => q(ㄌㄩㄝ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:lüe)),
					result  => q(ㄌㄩㄝ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:lue)),
					result  => q(ㄌㄩㄝ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:lue)),
					result  => q(ㄌㄩㄝ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:la)),
					result  => q(ㄌㄚ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:la)),
					result  => q(ㄌㄚ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:lo)),
					result  => q(ㄌㄛ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:lo)),
					result  => q(ㄌㄛ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:le)),
					result  => q(ㄌㄜ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:le)),
					result  => q(ㄌㄜ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:li)),
					result  => q(ㄌㄧ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:li)),
					result  => q(ㄌㄧ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:lu)),
					result  => q(ㄌㄨ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:lu)),
					result  => q(ㄌㄨ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:lü)),
					result  => q(ㄌㄩ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:lü)),
					result  => q(ㄌㄩ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:guang)),
					result  => q(ㄍㄨㄤ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:guang)),
					result  => q(ㄍㄨㄤ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:gang)),
					result  => q(ㄍㄤ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:gang)),
					result  => q(ㄍㄤ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:geng)),
					result  => q(ㄍㄥ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:geng)),
					result  => q(ㄍㄥ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:guai)),
					result  => q(ㄍㄨㄞ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:guai)),
					result  => q(ㄍㄨㄞ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:guan)),
					result  => q(ㄍㄨㄢ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:guan)),
					result  => q(ㄍㄨㄢ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:gong)),
					result  => q(ㄍㄨㄥ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:gong)),
					result  => q(ㄍㄨㄥ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:gai)),
					result  => q(ㄍㄞ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:gai)),
					result  => q(ㄍㄞ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:gei)),
					result  => q(ㄍㄟ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:gei)),
					result  => q(ㄍㄟ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:gao)),
					result  => q(ㄍㄠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:gao)),
					result  => q(ㄍㄠ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:gou)),
					result  => q(ㄍㄡ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:gou)),
					result  => q(ㄍㄡ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:gan)),
					result  => q(ㄍㄢ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:gan)),
					result  => q(ㄍㄢ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:gen)),
					result  => q(ㄍㄣ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:gen)),
					result  => q(ㄍㄣ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:gua)),
					result  => q(ㄍㄨㄚ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:gua)),
					result  => q(ㄍㄨㄚ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:guo)),
					result  => q(ㄍㄨㄛ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:guo)),
					result  => q(ㄍㄨㄛ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:gui)),
					result  => q(ㄍㄨㄟ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:gui)),
					result  => q(ㄍㄨㄟ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:gun)),
					result  => q(ㄍㄨㄣ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:gun)),
					result  => q(ㄍㄨㄣ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:ga)),
					result  => q(ㄍㄚ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ga)),
					result  => q(ㄍㄚ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:ge)),
					result  => q(ㄍㄜ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ge)),
					result  => q(ㄍㄜ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:gi)),
					result  => q(ㄍㄧ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:gi)),
					result  => q(ㄍㄧ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:gu)),
					result  => q(ㄍㄨ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:gu)),
					result  => q(ㄍㄨ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:kuang)),
					result  => q(ㄎㄨㄤ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:kuang)),
					result  => q(ㄎㄨㄤ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:kang)),
					result  => q(ㄎㄤ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:kang)),
					result  => q(ㄎㄤ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:keng)),
					result  => q(ㄎㄥ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:keng)),
					result  => q(ㄎㄥ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:kuai)),
					result  => q(ㄎㄨㄞ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:kuai)),
					result  => q(ㄎㄨㄞ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:kuan)),
					result  => q(ㄎㄨㄢ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:kuan)),
					result  => q(ㄎㄨㄢ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:kong)),
					result  => q(ㄎㄨㄥ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:kong)),
					result  => q(ㄎㄨㄥ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:kai)),
					result  => q(ㄎㄞ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:kai)),
					result  => q(ㄎㄞ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:kao)),
					result  => q(ㄎㄠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:kao)),
					result  => q(ㄎㄠ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:kou)),
					result  => q(ㄎㄡ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:kou)),
					result  => q(ㄎㄡ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:kan)),
					result  => q(ㄎㄢ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:kan)),
					result  => q(ㄎㄢ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:ken)),
					result  => q(ㄎㄣ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ken)),
					result  => q(ㄎㄣ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:kua)),
					result  => q(ㄎㄨㄚ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:kua)),
					result  => q(ㄎㄨㄚ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:kuo)),
					result  => q(ㄎㄨㄛ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:kuo)),
					result  => q(ㄎㄨㄛ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:kui)),
					result  => q(ㄎㄨㄟ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:kui)),
					result  => q(ㄎㄨㄟ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:kun)),
					result  => q(ㄎㄨㄣ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:kun)),
					result  => q(ㄎㄨㄣ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:ka)),
					result  => q(ㄎㄚ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ka)),
					result  => q(ㄎㄚ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:ke)),
					result  => q(ㄎㄜ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ke)),
					result  => q(ㄎㄜ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:ku)),
					result  => q(ㄎㄨ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ku)),
					result  => q(ㄎㄨ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:huang)),
					result  => q(ㄏㄨㄤ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:huang)),
					result  => q(ㄏㄨㄤ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:hang)),
					result  => q(ㄏㄤ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:hang)),
					result  => q(ㄏㄤ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:heng)),
					result  => q(ㄏㄥ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:heng)),
					result  => q(ㄏㄥ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:huai)),
					result  => q(ㄏㄨㄞ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:huai)),
					result  => q(ㄏㄨㄞ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:huan)),
					result  => q(ㄏㄨㄢ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:huan)),
					result  => q(ㄏㄨㄢ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:hong)),
					result  => q(ㄏㄨㄥ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:hong)),
					result  => q(ㄏㄨㄥ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:hai)),
					result  => q(ㄏㄞ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:hai)),
					result  => q(ㄏㄞ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:hei)),
					result  => q(ㄏㄟ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:hei)),
					result  => q(ㄏㄟ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:hao)),
					result  => q(ㄏㄠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:hao)),
					result  => q(ㄏㄠ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:hou)),
					result  => q(ㄏㄡ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:hou)),
					result  => q(ㄏㄡ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:han)),
					result  => q(ㄏㄢ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:han)),
					result  => q(ㄏㄢ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:hen)),
					result  => q(ㄏㄣ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:hen)),
					result  => q(ㄏㄣ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:hua)),
					result  => q(ㄏㄨㄚ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:hua)),
					result  => q(ㄏㄨㄚ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:huo)),
					result  => q(ㄏㄨㄛ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:huo)),
					result  => q(ㄏㄨㄛ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:hui)),
					result  => q(ㄏㄨㄟ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:hui)),
					result  => q(ㄏㄨㄟ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:hun)),
					result  => q(ㄏㄨㄣ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:hun)),
					result  => q(ㄏㄨㄣ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:hm)),
					result  => q(ㄏㄇ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:hm)),
					result  => q(ㄏㄇ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:ha)),
					result  => q(ㄏㄚ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ha)),
					result  => q(ㄏㄚ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:ho)),
					result  => q(ㄏㄛ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ho)),
					result  => q(ㄏㄛ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:he)),
					result  => q(ㄏㄜ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:he)),
					result  => q(ㄏㄜ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:hu)),
					result  => q(ㄏㄨ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:hu)),
					result  => q(ㄏㄨ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:jiang)),
					result  => q(ㄐㄧㄤ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:jiang)),
					result  => q(ㄐㄧㄤ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:jiong)),
					result  => q(ㄐㄩㄥ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:jiong)),
					result  => q(ㄐㄩㄥ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:jiao)),
					result  => q(ㄐㄧㄠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:jiao)),
					result  => q(ㄐㄧㄠ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:jian)),
					result  => q(ㄐㄧㄢ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:jian)),
					result  => q(ㄐㄧㄢ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:jing)),
					result  => q(ㄐㄧㄥ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:jing)),
					result  => q(ㄐㄧㄥ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:juan)),
					result  => q(ㄐㄩㄢ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:juan)),
					result  => q(ㄐㄩㄢ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:jia)),
					result  => q(ㄐㄧㄚ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:jia)),
					result  => q(ㄐㄧㄚ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:jie)),
					result  => q(ㄐㄧㄝ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:jie)),
					result  => q(ㄐㄧㄝ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:jiu)),
					result  => q(ㄐㄧㄡ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:jiu)),
					result  => q(ㄐㄧㄡ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:jin)),
					result  => q(ㄐㄧㄣ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:jin)),
					result  => q(ㄐㄧㄣ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:jue)),
					result  => q(ㄐㄩㄝ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:jue)),
					result  => q(ㄐㄩㄝ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:jun)),
					result  => q(ㄐㄩㄣ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:jun)),
					result  => q(ㄐㄩㄣ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:ji)),
					result  => q(ㄐㄧ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ji)),
					result  => q(ㄐㄧ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:ju)),
					result  => q(ㄐㄩ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ju)),
					result  => q(ㄐㄩ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:qiang)),
					result  => q(ㄑㄧㄤ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:qiang)),
					result  => q(ㄑㄧㄤ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:qiong)),
					result  => q(ㄑㄩㄥ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:qiong)),
					result  => q(ㄑㄩㄥ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:qiao)),
					result  => q(ㄑㄧㄠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:qiao)),
					result  => q(ㄑㄧㄠ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:qian)),
					result  => q(ㄑㄧㄢ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:qian)),
					result  => q(ㄑㄧㄢ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:qing)),
					result  => q(ㄑㄧㄥ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:qing)),
					result  => q(ㄑㄧㄥ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:quan)),
					result  => q(ㄑㄩㄢ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:quan)),
					result  => q(ㄑㄩㄢ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:qia)),
					result  => q(ㄑㄧㄚ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:qia)),
					result  => q(ㄑㄧㄚ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:qie)),
					result  => q(ㄑㄧㄝ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:qie)),
					result  => q(ㄑㄧㄝ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:qiu)),
					result  => q(ㄑㄧㄡ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:qiu)),
					result  => q(ㄑㄧㄡ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:qin)),
					result  => q(ㄑㄧㄣ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:qin)),
					result  => q(ㄑㄧㄣ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:que)),
					result  => q(ㄑㄩㄝ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:que)),
					result  => q(ㄑㄩㄝ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:qun)),
					result  => q(ㄑㄩㄣ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:qun)),
					result  => q(ㄑㄩㄣ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:qi)),
					result  => q(ㄑㄧ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:qi)),
					result  => q(ㄑㄧ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:qu)),
					result  => q(ㄑㄩ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:qu)),
					result  => q(ㄑㄩ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:xiang)),
					result  => q(ㄒㄧㄤ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:xiang)),
					result  => q(ㄒㄧㄤ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:xiong)),
					result  => q(ㄒㄩㄥ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:xiong)),
					result  => q(ㄒㄩㄥ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:xiao)),
					result  => q(ㄒㄧㄠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:xiao)),
					result  => q(ㄒㄧㄠ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:xian)),
					result  => q(ㄒㄧㄢ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:xian)),
					result  => q(ㄒㄧㄢ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:xing)),
					result  => q(ㄒㄧㄥ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:xing)),
					result  => q(ㄒㄧㄥ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:xuan)),
					result  => q(ㄒㄩㄢ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:xuan)),
					result  => q(ㄒㄩㄢ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:xia)),
					result  => q(ㄒㄧㄚ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:xia)),
					result  => q(ㄒㄧㄚ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:xie)),
					result  => q(ㄒㄧㄝ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:xie)),
					result  => q(ㄒㄧㄝ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:xiu)),
					result  => q(ㄒㄧㄡ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:xiu)),
					result  => q(ㄒㄧㄡ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:xin)),
					result  => q(ㄒㄧㄣ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:xin)),
					result  => q(ㄒㄧㄣ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:xue)),
					result  => q(ㄒㄩㄝ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:xue)),
					result  => q(ㄒㄩㄝ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:xun)),
					result  => q(ㄒㄩㄣ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:xun)),
					result  => q(ㄒㄩㄣ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:xi)),
					result  => q(ㄒㄧ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:xi)),
					result  => q(ㄒㄧ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:xu)),
					result  => q(ㄒㄩ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:xu)),
					result  => q(ㄒㄩ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:zhuang)),
					result  => q(ㄓㄨㄤ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:zhuang)),
					result  => q(ㄓㄨㄤ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:zhang)),
					result  => q(ㄓㄤ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:zhang)),
					result  => q(ㄓㄤ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:zheng)),
					result  => q(ㄓㄥ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:zheng)),
					result  => q(ㄓㄥ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:zhuai)),
					result  => q(ㄓㄨㄞ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:zhuai)),
					result  => q(ㄓㄨㄞ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:zhuan)),
					result  => q(ㄓㄨㄢ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:zhuan)),
					result  => q(ㄓㄨㄢ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:zhong)),
					result  => q(ㄓㄨㄥ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:zhong)),
					result  => q(ㄓㄨㄥ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:zhai)),
					result  => q(ㄓㄞ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:zhai)),
					result  => q(ㄓㄞ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:zhei)),
					result  => q(ㄓㄟ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:zhei)),
					result  => q(ㄓㄟ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:zhao)),
					result  => q(ㄓㄠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:zhao)),
					result  => q(ㄓㄠ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:zhou)),
					result  => q(ㄓㄡ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:zhou)),
					result  => q(ㄓㄡ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:zhan)),
					result  => q(ㄓㄢ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:zhan)),
					result  => q(ㄓㄢ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:zhen)),
					result  => q(ㄓㄣ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:zhen)),
					result  => q(ㄓㄣ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:zhua)),
					result  => q(ㄓㄨㄚ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:zhua)),
					result  => q(ㄓㄨㄚ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:zhuo)),
					result  => q(ㄓㄨㄛ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:zhuo)),
					result  => q(ㄓㄨㄛ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:zhui)),
					result  => q(ㄓㄨㄟ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:zhui)),
					result  => q(ㄓㄨㄟ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:zhun)),
					result  => q(ㄓㄨㄣ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:zhun)),
					result  => q(ㄓㄨㄣ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:zha)),
					result  => q(ㄓㄚ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:zha)),
					result  => q(ㄓㄚ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:zhe)),
					result  => q(ㄓㄜ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:zhe)),
					result  => q(ㄓㄜ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:zhu)),
					result  => q(ㄓㄨ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:zhu)),
					result  => q(ㄓㄨ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:zhi)),
					result  => q(ㄓ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:zhi)),
					result  => q(ㄓ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:chuang)),
					result  => q(ㄔㄨㄤ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:chuang)),
					result  => q(ㄔㄨㄤ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:chang)),
					result  => q(ㄔㄤ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:chang)),
					result  => q(ㄔㄤ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:cheng)),
					result  => q(ㄔㄥ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:cheng)),
					result  => q(ㄔㄥ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:chuai)),
					result  => q(ㄔㄨㄞ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:chuai)),
					result  => q(ㄔㄨㄞ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:chuan)),
					result  => q(ㄔㄨㄢ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:chuan)),
					result  => q(ㄔㄨㄢ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:chong)),
					result  => q(ㄔㄨㄥ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:chong)),
					result  => q(ㄔㄨㄥ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:chai)),
					result  => q(ㄔㄞ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:chai)),
					result  => q(ㄔㄞ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:chao)),
					result  => q(ㄔㄠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:chao)),
					result  => q(ㄔㄠ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:chou)),
					result  => q(ㄔㄡ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:chou)),
					result  => q(ㄔㄡ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:chan)),
					result  => q(ㄔㄢ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:chan)),
					result  => q(ㄔㄢ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:chen)),
					result  => q(ㄔㄣ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:chen)),
					result  => q(ㄔㄣ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:chua)),
					result  => q(ㄔㄨㄚ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:chua)),
					result  => q(ㄔㄨㄚ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:chuo)),
					result  => q(ㄔㄨㄛ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:chuo)),
					result  => q(ㄔㄨㄛ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:chui)),
					result  => q(ㄔㄨㄟ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:chui)),
					result  => q(ㄔㄨㄟ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:chun)),
					result  => q(ㄔㄨㄣ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:chun)),
					result  => q(ㄔㄨㄣ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:cha)),
					result  => q(ㄔㄚ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:cha)),
					result  => q(ㄔㄚ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:che)),
					result  => q(ㄔㄜ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:che)),
					result  => q(ㄔㄜ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:chu)),
					result  => q(ㄔㄨ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:chu)),
					result  => q(ㄔㄨ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:chi)),
					result  => q(ㄔ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:chi)),
					result  => q(ㄔ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:shuang)),
					result  => q(ㄕㄨㄤ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:shuang)),
					result  => q(ㄕㄨㄤ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:shong)),
					result  => q(ㄕㄡㄥ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:shong)),
					result  => q(ㄕㄡㄥ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:shang)),
					result  => q(ㄕㄤ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:shang)),
					result  => q(ㄕㄤ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:sheng)),
					result  => q(ㄕㄥ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:sheng)),
					result  => q(ㄕㄥ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:shuai)),
					result  => q(ㄕㄨㄞ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:shuai)),
					result  => q(ㄕㄨㄞ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:shuan)),
					result  => q(ㄕㄨㄢ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:shuan)),
					result  => q(ㄕㄨㄢ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:shai)),
					result  => q(ㄕㄞ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:shai)),
					result  => q(ㄕㄞ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:shei)),
					result  => q(ㄕㄟ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:shei)),
					result  => q(ㄕㄟ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:shao)),
					result  => q(ㄕㄠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:shao)),
					result  => q(ㄕㄠ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:shou)),
					result  => q(ㄕㄡ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:shou)),
					result  => q(ㄕㄡ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:shan)),
					result  => q(ㄕㄢ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:shan)),
					result  => q(ㄕㄢ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:shen)),
					result  => q(ㄕㄣ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:shen)),
					result  => q(ㄕㄣ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:shua)),
					result  => q(ㄕㄨㄚ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:shua)),
					result  => q(ㄕㄨㄚ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:shuo)),
					result  => q(ㄕㄨㄛ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:shuo)),
					result  => q(ㄕㄨㄛ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:shui)),
					result  => q(ㄕㄨㄟ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:shui)),
					result  => q(ㄕㄨㄟ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:shun)),
					result  => q(ㄕㄨㄣ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:shun)),
					result  => q(ㄕㄨㄣ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:sha)),
					result  => q(ㄕㄚ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:sha)),
					result  => q(ㄕㄚ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:she)),
					result  => q(ㄕㄜ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:she)),
					result  => q(ㄕㄜ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:shu)),
					result  => q(ㄕㄨ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:shu)),
					result  => q(ㄕㄨ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:shi)),
					result  => q(ㄕ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:shi)),
					result  => q(ㄕ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:rang)),
					result  => q(ㄖㄤ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:rang)),
					result  => q(ㄖㄤ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:reng)),
					result  => q(ㄖㄥ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:reng)),
					result  => q(ㄖㄥ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:ruan)),
					result  => q(ㄖㄨㄢ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ruan)),
					result  => q(ㄖㄨㄢ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:rong)),
					result  => q(ㄖㄨㄥ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:rong)),
					result  => q(ㄖㄨㄥ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:rao)),
					result  => q(ㄖㄠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:rao)),
					result  => q(ㄖㄠ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:rou)),
					result  => q(ㄖㄡ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:rou)),
					result  => q(ㄖㄡ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:ran)),
					result  => q(ㄖㄢ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ran)),
					result  => q(ㄖㄢ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:ren)),
					result  => q(ㄖㄣ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ren)),
					result  => q(ㄖㄣ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:ruo)),
					result  => q(ㄖㄨㄛ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ruo)),
					result  => q(ㄖㄨㄛ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:rui)),
					result  => q(ㄖㄨㄟ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:rui)),
					result  => q(ㄖㄨㄟ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:run)),
					result  => q(ㄖㄨㄣ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:run)),
					result  => q(ㄖㄨㄣ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:ra)),
					result  => q(ㄖㄚ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ra)),
					result  => q(ㄖㄚ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:re)),
					result  => q(ㄖㄜ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:re)),
					result  => q(ㄖㄜ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:ru)),
					result  => q(ㄖㄨ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ru)),
					result  => q(ㄖㄨ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:ri)),
					result  => q(ㄖ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ri)),
					result  => q(ㄖ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:zang)),
					result  => q(ㄗㄤ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:zang)),
					result  => q(ㄗㄤ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:zeng)),
					result  => q(ㄗㄥ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:zeng)),
					result  => q(ㄗㄥ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:zuan)),
					result  => q(ㄗㄨㄢ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:zuan)),
					result  => q(ㄗㄨㄢ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:zong)),
					result  => q(ㄗㄨㄥ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:zong)),
					result  => q(ㄗㄨㄥ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:zai)),
					result  => q(ㄗㄞ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:zai)),
					result  => q(ㄗㄞ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:zei)),
					result  => q(ㄗㄟ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:zei)),
					result  => q(ㄗㄟ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:zao)),
					result  => q(ㄗㄠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:zao)),
					result  => q(ㄗㄠ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:zou)),
					result  => q(ㄗㄡ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:zou)),
					result  => q(ㄗㄡ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:zan)),
					result  => q(ㄗㄢ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:zan)),
					result  => q(ㄗㄢ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:zen)),
					result  => q(ㄗㄣ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:zen)),
					result  => q(ㄗㄣ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:zuo)),
					result  => q(ㄗㄨㄛ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:zuo)),
					result  => q(ㄗㄨㄛ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:zui)),
					result  => q(ㄗㄨㄟ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:zui)),
					result  => q(ㄗㄨㄟ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:zun)),
					result  => q(ㄗㄨㄣ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:zun)),
					result  => q(ㄗㄨㄣ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:za)),
					result  => q(ㄗㄚ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:za)),
					result  => q(ㄗㄚ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:ze)),
					result  => q(ㄗㄜ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ze)),
					result  => q(ㄗㄜ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:zu)),
					result  => q(ㄗㄨ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:zu)),
					result  => q(ㄗㄨ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:zi)),
					result  => q(ㄗ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:zi)),
					result  => q(ㄗ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:cang)),
					result  => q(ㄘㄤ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:cang)),
					result  => q(ㄘㄤ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:ceng)),
					result  => q(ㄘㄥ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ceng)),
					result  => q(ㄘㄥ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:cuan)),
					result  => q(ㄘㄨㄢ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:cuan)),
					result  => q(ㄘㄨㄢ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:cong)),
					result  => q(ㄘㄨㄥ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:cong)),
					result  => q(ㄘㄨㄥ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:cai)),
					result  => q(ㄘㄞ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:cai)),
					result  => q(ㄘㄞ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:cao)),
					result  => q(ㄘㄠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:cao)),
					result  => q(ㄘㄠ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:cou)),
					result  => q(ㄘㄡ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:cou)),
					result  => q(ㄘㄡ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:can)),
					result  => q(ㄘㄢ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:can)),
					result  => q(ㄘㄢ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:cen)),
					result  => q(ㄘㄣ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:cen)),
					result  => q(ㄘㄣ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:cuo)),
					result  => q(ㄘㄨㄛ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:cuo)),
					result  => q(ㄘㄨㄛ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:cui)),
					result  => q(ㄘㄨㄟ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:cui)),
					result  => q(ㄘㄨㄟ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:cun)),
					result  => q(ㄘㄨㄣ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:cun)),
					result  => q(ㄘㄨㄣ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:ca)),
					result  => q(ㄘㄚ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ca)),
					result  => q(ㄘㄚ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:ce)),
					result  => q(ㄘㄜ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ce)),
					result  => q(ㄘㄜ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:cu)),
					result  => q(ㄘㄨ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:cu)),
					result  => q(ㄘㄨ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:ci)),
					result  => q(ㄘ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ci)),
					result  => q(ㄘ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:sang)),
					result  => q(ㄙㄤ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:sang)),
					result  => q(ㄙㄤ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:seng)),
					result  => q(ㄙㄥ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:seng)),
					result  => q(ㄙㄥ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:suan)),
					result  => q(ㄙㄨㄢ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:suan)),
					result  => q(ㄙㄨㄢ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:song)),
					result  => q(ㄙㄨㄥ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:song)),
					result  => q(ㄙㄨㄥ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:sai)),
					result  => q(ㄙㄞ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:sai)),
					result  => q(ㄙㄞ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:sei)),
					result  => q(ㄙㄟ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:sei)),
					result  => q(ㄙㄟ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:sao)),
					result  => q(ㄙㄠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:sao)),
					result  => q(ㄙㄠ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:sou)),
					result  => q(ㄙㄡ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:sou)),
					result  => q(ㄙㄡ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:san)),
					result  => q(ㄙㄢ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:san)),
					result  => q(ㄙㄢ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:sen)),
					result  => q(ㄙㄣ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:sen)),
					result  => q(ㄙㄣ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:suo)),
					result  => q(ㄙㄨㄛ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:suo)),
					result  => q(ㄙㄨㄛ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:sui)),
					result  => q(ㄙㄨㄟ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:sui)),
					result  => q(ㄙㄨㄟ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:sun)),
					result  => q(ㄙㄨㄣ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:sun)),
					result  => q(ㄙㄨㄣ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:sa)),
					result  => q(ㄙㄚ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:sa)),
					result  => q(ㄙㄚ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:se)),
					result  => q(ㄙㄜ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:se)),
					result  => q(ㄙㄜ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:su)),
					result  => q(ㄙㄨ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:su)),
					result  => q(ㄙㄨ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:si)),
					result  => q(ㄙ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:si)),
					result  => q(ㄙ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:yuan)),
					result  => q(ㄩㄢ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:yuan)),
					result  => q(ㄩㄢ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:yong)),
					result  => q(ㄩㄥ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:yong)),
					result  => q(ㄩㄥ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:yue)),
					result  => q(ㄩㄝ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:yue)),
					result  => q(ㄩㄝ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:yun)),
					result  => q(ㄩㄣ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:yun)),
					result  => q(ㄩㄣ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:yu)),
					result  => q(ㄩ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:yu)),
					result  => q(ㄩ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:yang)),
					result  => q(ㄧㄤ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:yang)),
					result  => q(ㄧㄤ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:ying)),
					result  => q(ㄧㄥ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ying)),
					result  => q(ㄧㄥ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:yai)),
					result  => q(ㄧㄞ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:yai)),
					result  => q(ㄧㄞ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:yao)),
					result  => q(ㄧㄠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:yao)),
					result  => q(ㄧㄠ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:you)),
					result  => q(ㄧㄡ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:you)),
					result  => q(ㄧㄡ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:yan)),
					result  => q(ㄧㄢ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:yan)),
					result  => q(ㄧㄢ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:yin)),
					result  => q(ㄧㄣ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:yin)),
					result  => q(ㄧㄣ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:ya)),
					result  => q(ㄧㄚ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ya)),
					result  => q(ㄧㄚ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:yo)),
					result  => q(ㄧㄛ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:yo)),
					result  => q(ㄧㄛ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:ye)),
					result  => q(ㄧㄝ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ye)),
					result  => q(ㄧㄝ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:yi)),
					result  => q(ㄧ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:yi)),
					result  => q(ㄧ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:wong)),
					result  => q(ㄨㄨㄥ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:wong)),
					result  => q(ㄨㄨㄥ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:wang)),
					result  => q(ㄨㄤ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:wang)),
					result  => q(ㄨㄤ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:weng)),
					result  => q(ㄨㄥ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:weng)),
					result  => q(ㄨㄥ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:wai)),
					result  => q(ㄨㄞ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:wai)),
					result  => q(ㄨㄞ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:wei)),
					result  => q(ㄨㄟ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:wei)),
					result  => q(ㄨㄟ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:wan)),
					result  => q(ㄨㄢ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:wan)),
					result  => q(ㄨㄢ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:wen)),
					result  => q(ㄨㄣ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:wen)),
					result  => q(ㄨㄣ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:wa)),
					result  => q(ㄨㄚ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:wa)),
					result  => q(ㄨㄚ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:wo)),
					result  => q(ㄨㄛ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:wo)),
					result  => q(ㄨㄛ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:wu)),
					result  => q(ㄨ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:wu)),
					result  => q(ㄨ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:ang)),
					result  => q(ㄤ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ang)),
					result  => q(ㄤ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:eng)),
					result  => q(ㄥ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:eng)),
					result  => q(ㄥ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:eh)),
					result  => q(ㄝ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:eh)),
					result  => q(ㄝ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:ea)),
					result  => q(ㄝ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ea)),
					result  => q(ㄝ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:ai)),
					result  => q(ㄞ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ai)),
					result  => q(ㄞ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:ei)),
					result  => q(ㄟ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ei)),
					result  => q(ㄟ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:ao)),
					result  => q(ㄠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ao)),
					result  => q(ㄠ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:au)),
					result  => q(ㄠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:au)),
					result  => q(ㄠ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:ou)),
					result  => q(ㄡ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ou)),
					result  => q(ㄡ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:an)),
					result  => q(ㄢ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:an)),
					result  => q(ㄢ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:en)),
					result  => q(ㄣ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:en)),
					result  => q(ㄣ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:er)),
					result  => q(ㄦ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:er)),
					result  => q(ㄦ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:a)),
					result  => q(ㄚ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:a)),
					result  => q(ㄚ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:o)),
					result  => q(ㄛ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:o)),
					result  => q(ㄛ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:e)),
					result  => q(ㄜ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:e)),
					result  => q(ㄜ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:iu)),
					result  => q(ㄩ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:iu)),
					result  => q(ㄩ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:i)),
					result  => q(ㄧ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:i)),
					result  => q(ㄧ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:u)),
					result  => q(ㄨ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:u)),
					result  => q(ㄨ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:m)),
					result  => q(ㄇ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:m)),
					result  => q(ㄇ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q((?^u:[1-5])),
					replace => q((?^u:n)),
					result  => q(ㄋ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:n)),
					result  => q(ㄋ˙),
					revisit => 0,
				},
				{
					before  => q((?^u:#[b p m f d t n l g k h j q x r z c s])),
					after   => q((?^u:[1-5])),
					replace => q((?^u:ia)),
					result  => q(ㄧㄚ),
					revisit => 0,
				},
				{
					before  => q((?^u:#[b p m f d t n l g k h j q x r z c s])),
					after   => q(),
					replace => q((?^u:ia)),
					result  => q(ㄧㄚ˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:#ia)),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:#ie)),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:#iao)),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:#iu)),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:#ian)),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:#in)),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:#iang)),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:#ing)),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:#ua)),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:#uo)),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:#uai)),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:#ui)),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:#uang)),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:#ong)),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:#iong)),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:b)),
					result  => q(ㄅ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:p)),
					result  => q(ㄆ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:#m)),
					result  => q(ㄇ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:f)),
					result  => q(ㄈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:d)),
					result  => q(ㄉ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:t)),
					result  => q(ㄊ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:#n)),
					result  => q(ㄋ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:l)),
					result  => q(ㄌ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:g)),
					result  => q(ㄍ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:k)),
					result  => q(ㄎ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:h)),
					result  => q(ㄏ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:j)),
					result  => q(ㄐ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:q)),
					result  => q(ㄑ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:x)),
					result  => q(ㄒ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:zh)),
					result  => q(ㄓ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:ch)),
					result  => q(ㄔ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:sh)),
					result  => q(ㄕ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:r)),
					result  => q(ㄖ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:z)),
					result  => q(ㄗ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:c)),
					result  => q(ㄘ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:s)),
					result  => q(ㄙ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:#tone1:pinyin\u0304or1)),
					result  => q(zhuyintypicallyunmarkedoruseˉ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:1)),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q((?^u:#(?[[a-z] - [b p f d t l g k h j q x r z c s]]))),
					after   => q(),
					replace => q((?^u:2)),
					result  => q(ˊ),
					revisit => 0,
				},
				{
					before  => q((?^u:#(?[[a-z] - [b p f d t l g k h j q x r z c s]]))),
					after   => q(),
					replace => q((?^u:3)),
					result  => q(ˇ),
					revisit => 0,
				},
				{
					before  => q((?^u:#(?[[a-z] - [b p f d t l g k h j q x r z c s]]))),
					after   => q(),
					replace => q((?^u:4)),
					result  => q(ˋ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:2)),
					result  => q(ˊ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:3)),
					result  => q(ˇ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:4)),
					result  => q(ˋ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:#tone5(light):pinyintypicallyunmarkedoruse5)),
					result  => q(zhuyin˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:5)),
					result  => q(˙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q((?^u:#)),
					result  => q(˙),
					revisit => 0,
				},
			]
		},
	] },
);

no Moose;
__PACKAGE__->meta->make_immutable;

1;

# vim: tabstop=4
